pub enum ModuleDetection {
Auto,
Legacy,
Force,
}Expand description
Specify how TypeScript determine a file as module. See more: https://www.typescriptlang.org/tsconfig/#moduleDetection
Variants
Auto
TypeScript will not only look for import and export statements, but it will also check whether the “type” field in a package.json is set to “module” when running with module: nodenext or node16, and check whether the current file is a JSX file when running under jsx: react-jsx
Legacy
The same behavior as 4.6 and prior, usings import and export statements to determine whether a file is a module.
Force
Ensures that every non-declaration file is treated as a module.