pub enum TypeAcquisition {
Bool(bool),
Object {
enable: bool,
include: Option<BTreeSet<String>>,
exclude: Option<BTreeSet<String>>,
disable_filename_based_type_acquisition: Option<bool>,
},
}Expand description
Auto type (.d.ts) acquisition options for this project. Requires TypeScript version 2.1 or later.
Variants
Bool(bool)
Object
Fields

include: Option<BTreeSet<String>>Specifies a list of type declarations to be included in auto type acquisition. Ex. [“jquery”, “lodash”]

exclude: Option<BTreeSet<String>>Specifies a list of type declarations to be excluded from auto type acquisition. Ex. [“jquery”, “lodash”]

disable_filename_based_type_acquisition: Option<bool>TypeScript’s type acquisition can infer what types should be added based on filenames in a project. This means that having a file like jquery.js in your project would automatically download the types for JQuery from DefinitelyTyped. You can disable this via disableFilenameBasedTypeAcquisition.
See more: https://www.typescriptlang.org/it/tsconfig/#type-disableFilenameBasedTypeAcquisition