pub struct TsConfig {
pub extends: Option<String>,
pub files: BTreeSet<String>,
pub exclude: BTreeSet<String>,
pub include: BTreeSet<String>,
pub references: BTreeSet<TsConfigReference>,
pub type_acquisition: Option<TypeAcquisition>,
pub watch_options: Option<WatchOptions>,
pub compiler_options: Option<CompilerOptions>,
}Expand description
A struct representing the contents of a tsconfig.json file.
Fields
extends: Option<String>Path to base configuration file to inherit from (requires TypeScript version 2.1 or later), or array of base files, with the rightmost files having the greater priority (requires TypeScript version 5.0 or later).
files: BTreeSet<String>If no ‘files’ or ‘include’ property is present in a tsconfig.json, the compiler defaults to including all files in the containing directory and subdirectories except those specified by ‘exclude’. When a ‘files’ property is specified, only those files and those specified by ‘include’ are included.
exclude: BTreeSet<String>Specifies a list of files to be excluded from compilation. The ‘exclude’ property only affects the files included via the ‘include’ property and not the ‘files’ property. Glob patterns require TypeScript version 2.0 or later.
include: BTreeSet<String>Specifies a list of glob patterns that match files to be included in compilation. If no ‘files’ or ‘include’ property is present in a tsconfig.json, the compiler defaults to including all files in the containing directory and subdirectories except those specified by ‘exclude’. Requires TypeScript version 2.0 or later.
references: BTreeSet<TsConfigReference>Referenced projects. Requires TypeScript version 3.0 or later.
type_acquisition: Option<TypeAcquisition>Auto type (.d.ts) acquisition options for this project. Requires TypeScript version 2.1 or later.
watch_options: Option<WatchOptions>Settings for the watch mode in TypeScript.
compiler_options: Option<CompilerOptions>Instructs the TypeScript compiler how to compile .ts files.