pub struct WatchOptions {
pub watch_file: Option<WatchFile>,
pub watch_directory: Option<WatchDirectory>,
pub exclude_files: BTreeSet<String>,
pub exclude_directories: BTreeSet<String>,
pub fallback_polling: Option<FallbackPolling>,
pub synchronous_watch_directory: Option<bool>,
}Expand description
Settings for the watch mode in TypeScript.
Fields
watch_file: Option<WatchFile>Specify how the TypeScript watch mode works.
See more: https://www.typescriptlang.org/tsconfig#watchFile
watch_directory: Option<WatchDirectory>Specify how directories are watched on systems that lack recursive file-watching functionality.
See more: https://www.typescriptlang.org/tsconfig#watchDirectory
exclude_files: BTreeSet<String>Remove a list of files from the watch mode’s processing.
See more: https://www.typescriptlang.org/tsconfig#excludeFiles
exclude_directories: BTreeSet<String>Remove a list of directories from the watch process.
See more: https://www.typescriptlang.org/tsconfig#excludeDirectories
fallback_polling: Option<FallbackPolling>Specify what approach the watcher should use if the system runs out of native file watchers.
See more: https://www.typescriptlang.org/tsconfig#fallbackPolling
synchronous_watch_directory: Option<bool>Synchronously call callbacks and update the state of directory watchers on platforms that don`t support recursive watching natively.
See more: https://www.typescriptlang.org/tsconfig#synchronousWatchDirectory