pub struct CompilerOptions {Show 109 fields
pub allow_arbitrary_extensions: Option<bool>,
pub allow_importing_ts_extensions: Option<bool>,
pub allow_js: Option<bool>,
pub allow_synthetic_default_imports: Option<bool>,
pub allow_umd_global_access: Option<bool>,
pub allow_unreachable_code: Option<bool>,
pub allow_unused_labels: Option<bool>,
pub always_strict: Option<bool>,
pub assume_changes_only_affect_direct_dependencies: Option<bool>,
pub base_url: Option<String>,
pub check_js: Option<bool>,
pub composite: Option<bool>,
pub custom_conditions: BTreeSet<String>,
pub declaration: Option<bool>,
pub declaration_dir: Option<String>,
pub declaration_map: Option<bool>,
pub disable_referenced_project_load: Option<bool>,
pub disable_size_limit: Option<bool>,
pub disable_solution_searching: Option<bool>,
pub disable_source_of_project_reference_redirect: Option<bool>,
pub downlevel_iteration: Option<bool>,
pub emit_bom: Option<bool>,
pub emit_declaration_only: Option<bool>,
pub emit_decorator_metadata: Option<bool>,
pub erasable_syntax_only: Option<bool>,
pub es_module_interop: Option<bool>,
pub exact_optional_property_types: Option<bool>,
pub extended_diagnostics: Option<bool>,
pub experimental_decorators: Option<bool>,
pub explain_files: Option<bool>,
pub force_consistent_casing_in_file_names: Option<bool>,
pub generate_trace: Option<bool>,
pub jsx: Option<Jsx>,
pub jsx_factory: Option<String>,
pub jsx_fragment_factory: Option<String>,
pub jsx_import_source: Option<String>,
pub lib: BTreeSet<Lib>,
pub lib_replacement: Option<bool>,
pub list_emitted_files: Option<bool>,
pub list_files: Option<bool>,
pub map_root: Option<String>,
pub max_node_module_js_depth: Option<u32>,
pub module: Option<Module>,
pub module_detection: Option<ModuleDetection>,
pub module_suffixes: BTreeSet<String>,
pub module_resolution: Option<ModuleResolution>,
pub new_line: Option<NewLine>,
pub no_check: Option<bool>,
pub no_emit: Option<bool>,
pub no_fallthrough_cases_in_switch: Option<bool>,
pub no_emit_helpers: Option<bool>,
pub no_emit_on_error: Option<bool>,
pub no_error_truncation: Option<bool>,
pub no_lib: Option<bool>,
pub no_implicit_any: Option<bool>,
pub no_implicit_override: Option<bool>,
pub no_implicit_returns: Option<bool>,
pub no_implicit_this: Option<bool>,
pub no_implicit_use_strict: Option<bool>,
pub no_property_access_from_index_signature: Option<bool>,
pub no_resolve: Option<bool>,
pub no_strict_generic_checks: Option<bool>,
pub no_unchecked_indexed_access: Option<bool>,
pub no_unchecked_side_effect_imports: Option<bool>,
pub no_unused_locals: Option<bool>,
pub no_unused_parameters: Option<bool>,
pub incremental: Option<bool>,
pub inline_sources: Option<bool>,
pub inline_source_map: Option<bool>,
pub import_helpers: Option<bool>,
pub isolated_declarations: Option<bool>,
pub isolated_modules: Option<bool>,
pub out_dir: Option<String>,
pub out_file: Option<String>,
pub paths: BTreeMap<String, BTreeSet<String>>,
pub plugins: BTreeSet<TsPlugin>,
pub preserve_const_enums: Option<bool>,
pub preserve_symlinks: Option<bool>,
pub preserve_watch_output: Option<bool>,
pub pretty: Option<bool>,
pub react_namespace: Option<String>,
pub remove_comments: Option<bool>,
pub resolve_json_module: Option<bool>,
pub root_dir: Option<String>,
pub root_dirs: BTreeSet<String>,
pub skip_default_lib_check: Option<bool>,
pub skip_lib_check: Option<bool>,
pub source_map: Option<bool>,
pub source_root: Option<String>,
pub strict: Option<bool>,
pub strict_bind_call_apply: Option<bool>,
pub strict_builtin_iterator_return: Option<bool>,
pub strict_function_types: Option<bool>,
pub strict_null_checks: Option<bool>,
pub strict_property_initialization: Option<bool>,
pub strip_internal: Option<bool>,
pub suppress_excess_property_errors: Option<bool>,
pub suppress_implicit_any_index_errors: Option<bool>,
pub target: Option<Target>,
pub trace_resolution: Option<bool>,
pub ts_build_info_file: Option<String>,
pub types: BTreeSet<String>,
pub type_roots: BTreeSet<String>,
pub resolve_package_json_exports: Option<bool>,
pub resolve_package_json_imports: Option<bool>,
pub rewrite_relative_imports_extensions: Option<bool>,
pub use_define_for_class_fields: Option<bool>,
pub use_unknown_in_catch_variables: Option<bool>,
pub verbatim_module_syntax: Option<bool>,
}Expand description
Instructs the TypeScript compiler how to compile .ts files.
Fields
allow_arbitrary_extensions: Option<bool>Enable importing files with any extension, provided a declaration file is present.
See more: https://www.typescriptlang.org/tsconfig#allowArbitraryExtensions
allow_importing_ts_extensions: Option<bool>Allow imports to include TypeScript file extensions. Requires either ‘–noEmit’ or ‘–emitDeclarationOnly’ to be set.
See more: https://www.typescriptlang.org/tsconfig#allowImportingTsExtensions
allow_js: Option<bool>Allow JavaScript files to be imported inside your project, instead of just .ts and .tsx files.
See more: https://www.typescriptlang.org/tsconfig/#allowJs
allow_synthetic_default_imports: Option<bool>Emit additional JavaScript to ease support for importing CommonJS modules. This enables allowSyntheticDefaultImports for type compatibility.
See more: https://www.typescriptlang.org/tsconfig#esModuleInterop
allow_umd_global_access: Option<bool>Allow accessing UMD globals from modules.
See more: https://www.typescriptlang.org/tsconfig#allowUmdGlobalAccess
allow_unreachable_code: Option<bool>Disable error reporting for unreachable code.
See more: https://www.typescriptlang.org/tsconfig#allowUnreachableCode
allow_unused_labels: Option<bool>Disable error reporting for unused labels.
See more: https://www.typescriptlang.org/tsconfig#allowUnusedLabels
always_strict: Option<bool>Ensures that your files are parsed in the ECMAScript strict mode, and emit “use strict” for each source file.
See more: https://www.typescriptlang.org/tsconfig/#alwaysStrict
assume_changes_only_affect_direct_dependencies: Option<bool>Have recompiles in ‘–incremental’ and ‘–watch’ assume that changes within a file will only affect files directly depending on it. Requires TypeScript version 3.8 or later.
See more: https://www.typescriptlang.org/tsconfig/#assumeChangesOnlyAffectDirectDependencies
base_url: Option<String>Specify the base directory to resolve non-relative module names.
See more: https://www.typescriptlang.org/tsconfig#baseUrl
check_js: Option<bool>Enable error reporting in type-checked JavaScript files.
See more: https://www.typescriptlang.org/tsconfig#checkJs
composite: Option<bool>Enable constraints that allow a TypeScript project to be used with project references.
See more: https://www.typescriptlang.org/tsconfig#composite
custom_conditions: BTreeSet<String>Conditions to set in addition to the resolver-specific defaults when resolving imports.
See more: https://www.typescriptlang.org/tsconfig#customConditions
declaration: Option<bool>Generate .d.ts files from TypeScript and JavaScript files in your project.
See more: https://www.typescriptlang.org/tsconfig#declaration
declaration_dir: Option<String>Specify the output directory for generated declaration files.
See more: https://www.typescriptlang.org/tsconfig#declarationDir
declaration_map: Option<bool>Create sourcemaps for d.ts files.
See more: https://www.typescriptlang.org/tsconfig#declarationMap
disable_referenced_project_load: Option<bool>Reduce the number of projects loaded automatically by TypeScript.
See more: https://www.typescriptlang.org/tsconfig#disableReferencedProjectLoad
disable_size_limit: Option<bool>Remove the 20mb cap on total source code size for JavaScript files in the TypeScript language server.
See more: https://www.typescriptlang.org/tsconfig#disableSizeLimit
disable_solution_searching: Option<bool>Opt a project out of multi-project reference checking when editing.
See more: https://www.typescriptlang.org/tsconfig#disableSolutionSearching
disable_source_of_project_reference_redirect: Option<bool>Disable preferring source files instead of declaration files when referencing composite projects.
See more: https://www.typescriptlang.org/tsconfig#disableSourceOfProjectReferenceRedirect
downlevel_iteration: Option<bool>Emit more compliant, but verbose and less performant JavaScript for iteration.
See more: https://www.typescriptlang.org/tsconfig#downlevelIteration
emit_bom: Option<bool>Emit a UTF-8 Byte Order Mark (BOM) in the beginning of output files.
See more: https://www.typescriptlang.org/tsconfig#emitBOM
emit_declaration_only: Option<bool>Only output d.ts files and not JavaScript files.
See more: https://www.typescriptlang.org/tsconfig#emitDeclarationOnly
emit_decorator_metadata: Option<bool>Emit design-type metadata for decorated declarations in source files.
See more: https://www.typescriptlang.org/tsconfig#emitDecoratorMetadata
erasable_syntax_only: Option<bool>Do not allow runtime constructs that are not part of ECMAScript.
See more: https://www.typescriptlang.org/tsconfig#erasableSyntaxOnly
es_module_interop: Option<bool>Emit additional JavaScript to ease support for importing CommonJS modules. This enables allowSyntheticDefaultImports for type compatibility.
See more: https://www.typescriptlang.org/tsconfig#esModuleInterop
exact_optional_property_types: Option<bool>Differentiate between undefined and not present when type checking.
See more: https://www.typescriptlang.org/tsconfig#exactOptionalPropertyTypes
extended_diagnostics: Option<bool>Output more detailed compiler performance information after building.
See more: https://www.typescriptlang.org/tsconfig#extendedDiagnostics
experimental_decorators: Option<bool>Enable experimental support for TC39 stage 2 draft decorators.
See more: https://www.typescriptlang.org/tsconfig#experimentalDecorators
explain_files: Option<bool>Print names of files which TypeScript sees as a part of your project and the reason they are part of the compilation.
See more: https://www.typescriptlang.org/tsconfig/#explainFiles
force_consistent_casing_in_file_names: Option<bool>Ensure that casing is correct in imports.
See more: https://www.typescriptlang.org/tsconfig#forceConsistentCasingInFileNames
generate_trace: Option<bool>Generates an event trace and a list of types.
See more: https://www.typescriptlang.org/tsconfig/#generateTrace
jsx: Option<Jsx>Specify what JSX code is generated.
See more: https://www.typescriptlang.org/tsconfig/#jsx
jsx_factory: Option<String>Specify the JSX factory function used when targeting React JSX emit, e.g. ‘React.createElement’ or ‘h’.
See more: https://www.typescriptlang.org/tsconfig#jsxFactory
jsx_fragment_factory: Option<String>Specify the JSX Fragment reference used for fragments when targeting React JSX emit e.g. ‘React.Fragment’ or ‘Fragment’.
See more: https://www.typescriptlang.org/tsconfig#jsxFragmentFactory
jsx_import_source: Option<String>Specify module specifier used to import the JSX factory functions when using jsx: react-jsx.
See more: https://www.typescriptlang.org/tsconfig#jsxImportSource
lib: BTreeSet<Lib>Specify a set of bundled library declaration files that describe the target runtime environment.
See more: https://www.typescriptlang.org/tsconfig#lib
lib_replacement: Option<bool>Enable lib replacement.
See more: https://www.typescriptlang.org/tsconfig#libReplacement
list_emitted_files: Option<bool>Print names of generated files part of the compilation to the terminal.
See more: https://www.typescriptlang.org/tsconfig/#listEmittedFiles
list_files: Option<bool>Print all of the files read during the compilation.
See more: https://www.typescriptlang.org/tsconfig#listFiles
map_root: Option<String>Specify the location where debugger should locate map files instead of generated locations.
See more: https://www.typescriptlang.org/tsconfig#mapRoot
max_node_module_js_depth: Option<u32>Specify the maximum folder depth used for checking JavaScript files from node_modules. Only applicable with allowJs.
See more: https://www.typescriptlang.org/tsconfig#maxNodeModuleJsDepth
module: Option<Module>Specify what module code is generated.
See more: https://www.typescriptlang.org/tsconfig#module
module_detection: Option<ModuleDetection>Specify how TypeScript determine a file as module.
See more: https://www.typescriptlang.org/tsconfig/#moduleDetection
module_suffixes: BTreeSet<String>Provides a way to override the default list of file name suffixes to search when resolving a module.
See more: https://www.typescriptlang.org/tsconfig/#moduleSuffixes
module_resolution: Option<ModuleResolution>Log paths used during the moduleResolution process.
See more: https://www.typescriptlang.org/tsconfig#traceResolution
new_line: Option<NewLine>Set the newline character for emitting files.
See more: https://www.typescriptlang.org/tsconfig#newLine
no_check: Option<bool>Disable full type checking (only critical parse and emit errors will be reported).
See more: https://www.typescriptlang.org/tsconfig#noCheck
no_emit: Option<bool>Disable emitting file from a compilation.
See more: https://www.typescriptlang.org/tsconfig#noEmit
no_fallthrough_cases_in_switch: Option<bool>Enable error reporting for fallthrough cases in switch statements.
See more: https://www.typescriptlang.org/tsconfig#noFallthroughCasesInSwitch
no_emit_helpers: Option<bool>Disable generating custom helper functions like __extends in compiled output.
See more: https://www.typescriptlang.org/tsconfig#noEmitHelpers
no_emit_on_error: Option<bool>Disable emitting files if any type checking errors are reported.
See more: https://www.typescriptlang.org/tsconfig#noEmitOnError
no_error_truncation: Option<bool>Disable truncating types in error messages.
See more: https://www.typescriptlang.org/tsconfig#noErrorTruncation
no_lib: Option<bool>Disable including any library files, including the default lib.d.ts.
See more: https://www.typescriptlang.org/tsconfig#noLib
no_implicit_any: Option<bool>Enable error reporting for expressions and declarations with an implied any type.
See more: https://www.typescriptlang.org/tsconfig#noImplicitAny
no_implicit_override: Option<bool>Ensure overriding members in derived classes are marked with an override modifier.
See more: https://www.typescriptlang.org/tsconfig#noImplicitOverride
no_implicit_returns: Option<bool>Enable error reporting for codepaths that do not explicitly return in a function.
See more: https://www.typescriptlang.org/tsconfig#noImplicitReturns
no_implicit_this: Option<bool>Enable error reporting when this is given the type any.
See more: https://www.typescriptlang.org/tsconfig#noImplicitThis
no_implicit_use_strict: Option<bool>Disable adding ‘use strict’ directives in emitted JavaScript files.
See more: https://www.typescriptlang.org/tsconfig#noImplicitUseStrict
no_property_access_from_index_signature: Option<bool>Enforces using indexed accessors for keys declared using an indexed type.
See more: https://www.typescriptlang.org/tsconfig#noPropertyAccessFromIndexSignature
no_resolve: Option<bool>Disallow imports, requires or <reference>s from expanding the number of files TypeScript should add to a project.
See more: https://www.typescriptlang.org/tsconfig#noResolve
no_strict_generic_checks: Option<bool>Disable strict checking of generic signatures in function types.
See more: https://www.typescriptlang.org/tsconfig#noStrictGenericChecks
no_unchecked_indexed_access: Option<bool>Add undefined to a type when accessed using an index.
See more: https://www.typescriptlang.org/tsconfig#noUncheckedIndexedAccess
no_unchecked_side_effect_imports: Option<bool>Check side effect imports.
See more: https://www.typescriptlang.org/tsconfig#noUncheckedSideEffectImports
no_unused_locals: Option<bool>Enable error reporting when a local variable isn’t read.
See more: https://www.typescriptlang.org/tsconfig#noUnusedLocals
no_unused_parameters: Option<bool>Raise an error when a function parameter isn’t read.
See more: https://www.typescriptlang.org/tsconfig#noUnusedParameters
incremental: Option<bool>Save .tsbuildinfo files to allow for incremental compilation of projects.
See more: https://www.typescriptlang.org/tsconfig#incremental
inline_sources: Option<bool>Include source code in the sourcemaps inside the emitted JavaScript.
See more: https://www.typescriptlang.org/tsconfig#inlineSources
inline_source_map: Option<bool>Include sourcemap files inside the emitted JavaScript.
See more: https://www.typescriptlang.org/tsconfig#inlineSourceMap
import_helpers: Option<bool>Allow importing helper functions from tslib once per project, instead of including them per-file.
See more: https://www.typescriptlang.org/tsconfig#importHelpers
isolated_declarations: Option<bool>Require sufficient annotation on exports so other tools can trivially generate declaration files.
See more: https://www.typescriptlang.org/tsconfig#isolatedDeclarations
isolated_modules: Option<bool>Ensure that each file can be safely transpiled without relying on other imports.
See more: https://www.typescriptlang.org/tsconfig#isolatedModules
out_dir: Option<String>Specify an output folder for all emitted files.
See more: https://www.typescriptlang.org/tsconfig#outDir
out_file: Option<String>Specify a file that bundles all outputs into one JavaScript file. If declaration is true, also designates a file that bundles all .d.ts output.
See more: https://www.typescriptlang.org/tsconfig#outFile
paths: BTreeMap<String, BTreeSet<String>>Specify a set of entries that re-map imports to additional lookup locations.
See more: https://www.typescriptlang.org/tsconfig/#paths
plugins: BTreeSet<TsPlugin>Specify a list of language service plugins to include.
See more: https://www.typescriptlang.org/tsconfig#plugins
preserve_const_enums: Option<bool>Disable erasing const enum declarations in generated code.
See more: https://www.typescriptlang.org/tsconfig#preserveConstEnums
preserve_symlinks: Option<bool>Disable resolving symlinks to their realpath. This correlates to the same flag in node.
See more: https://www.typescriptlang.org/tsconfig#preserveSymlinks
preserve_watch_output: Option<bool>Disable wiping the console in watch mode.
See more: https://www.typescriptlang.org/tsconfig#preserveWatchOutput
pretty: Option<bool>Enable color and formatting in output to make compiler errors easier to read.
See more: https://www.typescriptlang.org/tsconfig#pretty
react_namespace: Option<String>Specify the object invoked for createElement. This only applies when targeting react JSX emit.
See more: https://www.typescriptlang.org/tsconfig#reactNamespace
remove_comments: Option<bool>Disable emitting comments.
See more: https://www.typescriptlang.org/tsconfig#removeComments
resolve_json_module: Option<bool>Enable importing .json files.
See more: https://www.typescriptlang.org/tsconfig#resolveJsonModule
root_dir: Option<String>Specify the root folder within your source files.
See more: https://www.typescriptlang.org/tsconfig#rootDir
root_dirs: BTreeSet<String>Specify the root folder within your source files.
See more: https://www.typescriptlang.org/tsconfig#rootDir
skip_default_lib_check: Option<bool>Skip type checking .d.ts files that are included with TypeScript.
See more: https://www.typescriptlang.org/tsconfig#skipDefaultLibCheck
skip_lib_check: Option<bool>Skip type checking all .d.ts files.
See more: https://www.typescriptlang.org/tsconfig#skipLibCheck
source_map: Option<bool>Create source map files for emitted JavaScript files.
See more: https://www.typescriptlang.org/tsconfig#sourceMap
source_root: Option<String>Specify the root path for debuggers to find the reference source code.
See more: https://www.typescriptlang.org/tsconfig#sourceRoot
strict: Option<bool>Enable all strict type checking options.
See more: https://www.typescriptlang.org/tsconfig#strict
strict_bind_call_apply: Option<bool>Check that the arguments for bind, call, and apply methods match the original function.
See more: https://www.typescriptlang.org/tsconfig#strictBindCallApply
strict_builtin_iterator_return: Option<bool>Built-in iterators are instantiated with a ‘TReturn’ type of ‘undefined’ instead of ‘any’.
See more: https://www.typescriptlang.org/tsconfig#strictBuiltinIteratorReturn
strict_function_types: Option<bool>When assigning functions, check to ensure parameters and the return values are subtype-compatible.
See more: https://www.typescriptlang.org/tsconfig#strictFunctionTypes
strict_null_checks: Option<bool>When type checking, take into account null and undefined.
See more: https://www.typescriptlang.org/tsconfig#strictNullChecks
strict_property_initialization: Option<bool>Check for class properties that are declared but not set in the constructor.\n\n
See more: https://www.typescriptlang.org/tsconfig#strictPropertyInitialization
strip_internal: Option<bool>Disable emitting declarations that have @internal in their JSDoc comments.
See more: https://www.typescriptlang.org/tsconfig#stripInternal
suppress_excess_property_errors: Option<bool>Disable reporting of excess property errors during the creation of object literals.
See more: https://www.typescriptlang.org/tsconfig#suppressExcessPropertyErrors
suppress_implicit_any_index_errors: Option<bool>Suppress noImplicitAny errors when indexing objects that lack index signatures.
See more: https://www.typescriptlang.org/tsconfig#suppressImplicitAnyIndexErrors
target: Option<Target>Set the JavaScript language version for emitted JavaScript and include compatible library declarations.
See more: https://www.typescriptlang.org/tsconfig#target
trace_resolution: Option<bool>Log paths used during the moduleResolution process.
See more: https://www.typescriptlang.org/tsconfig#traceResolution
ts_build_info_file: Option<String>Specify the folder for .tsbuildinfo incremental compilation files.
See more: https://www.typescriptlang.org/tsconfig#tsBuildInfoFile
types: BTreeSet<String>Specify type package names to be included without being referenced in a source file.
See more: https://www.typescriptlang.org/tsconfig#types
type_roots: BTreeSet<String>Specify multiple folders that act like ./node_modules/@types.
See more: https://www.typescriptlang.org/tsconfig#typeRoots
resolve_package_json_exports: Option<bool>Use the package.json ‘exports’ field when resolving package imports.
See more: https://www.typescriptlang.org/tsconfig#resolvePackageJsonExports
resolve_package_json_imports: Option<bool>Use the package.json ‘imports’ field when resolving imports.
See more: https://www.typescriptlang.org/tsconfig#resolvePackageJsonImports
rewrite_relative_imports_extensions: Option<bool>Rewrite ‘.ts’, ‘.tsx’, ‘.mts’, and ‘.cts’ file extensions in relative import paths to their JavaScript equivalent in output files.
See more: https://www.typescriptlang.org/tsconfig#rewriteRelativeImportExtensions
use_define_for_class_fields: Option<bool>Emit ECMAScript-standard-compliant class fields.
See more: https://www.typescriptlang.org/tsconfig#useDefineForClassFields
use_unknown_in_catch_variables: Option<bool>Default catch clause variables as unknown instead of any.
See more: https://www.typescriptlang.org/tsconfig#useUnknownInCatchVariables
verbatim_module_syntax: Option<bool>Do not transform or elide any imports or exports not marked as type-only, ensuring they are written in the output file’s format based on the ‘module’ setting.
See more: https://www.typescriptlang.org/tsconfig#verbatimModuleSyntax